@@ -32,9 +32,11 @@ derivePlots <- function(x, y) {
 
   # determine rescaling factor
   if (length(y) > 1) {stop('"y" has more than 1 element')}
-
-  p <- rasterToPolygons(raster(extent(x), res=y, crs=crs(x))) # build grid
-  p <- crop(p, extent(x)) # crop grid by the reference object
+  e <- tryCatch(extent(x), error=function(i) return(TRUE))
+  if (is.logical(e)) stop('"x" is not a valid spatial object')
+  
+  p <- rasterToPolygons(raster(e, res=y, crs=crs(x))) # build grid
+  p <- crop(p, e) # crop grid by the reference object
   p <- p[round(area(p))==round(y*y),] # filter cells with an area smaller than intended
   
   return(p)
